/* Make the logo bigger */
.md-header__button.md-logo img,
.md-header__button.md-logo svg {
    height: 2.5rem;
    width: auto;
    max-width: none;
}

/* Dark mode aware logo - invert colors in dark mode */
[data-md-color-scheme="slate"] .md-header__button.md-logo img,
[data-md-color-scheme="slate"] .md-header__button.md-logo svg {
    filter: brightness(0) invert(1);
}

/* Light mode - keep original colors */
[data-md-color-scheme="default"] .md-header__button.md-logo img,
[data-md-color-scheme="default"] .md-header__button.md-logo svg {
    filter: none;
}

